@@ -8,7 +8,7 @@ Do not add this file to the repository.
 import datetime
 
 version = '2.4'
-date = 'Thu Oct 17 18:15:40 2019'
+date = 'Fri Oct 25 19:52:56 2019'
 
 # Was NetworkX built from a development version? If so, remember that the major
 # and minor versions reference the "target" (rather than "current") release.
@@ -18,7 +18,7 @@ dev = False
 version_info = ('networkx', '2', '4', None)
 
 # Format: a 'datetime.datetime' instance
-date_info = datetime.datetime(2019, 10, 17, 18, 15, 40)
+date_info = datetime.datetime(2019, 10, 25, 19, 52, 56)
 
 # Format: (vcs, vcs_tuple)
 vcs_info = (None, (None, None))
